@@ -22,11 +22,13 @@ def detect_terminyal_size() -> Tuple[int, int]:
     lines: Optional[int] = None
 
     envc = os.getenv('COLUMNS')
+    logging.debug(f'COLUMNS: {envc}')
     if envc:
         try: columns = int(envc)
         except ValueError: pass
 
     envl = os.getenv('LINES')
+    logging.debug(f'LINES: {envl}')
     if envl:
         try: lines = int(envl)
         except ValueError: pass
